@@ -27,7 +27,6 @@ from .orm_fields import (
     OrmFileField,
     OrmFkField,
     OrmRawField,
-    OrmURLField,
 )
 from .orm_functions import get_functions_for_type
 from .orm_types import get_field_type
@@ -360,15 +359,6 @@ def _get_fields_for_model(request, model, admin, admin_fields):
                 django_field=field,
             )
 
-        # URL's
-        elif isinstance(field, models.URLField):
-            fields[field_name] = OrmURLField(
-                model_name=model_name,
-                name=field_name,
-                pretty_name=pretty_name,
-                django_field=field,
-            )
-
         # Calculated and annotated fields
         elif isinstance(field, type(None)):
             orm_field = _get_calculated_field(
